==> tick-0.4.0-1.21.4-sources.jar: io/github/dennisochulor/tickrate/mixin/client/tick/ClientWorldMixin.java <==
package io.github.dennisochulor.tickrate.mixin.client.tick;

import io.github.dennisochulor.tickrate.TickRateClientManager;
import net.minecraft.class_1923;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_310;
import net.minecraft.class_5819;
import net.minecraft.class_638;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_638.class)
public class ClientWorldMixin {

    @Shadow @Final private class_310 client;

    @Inject(method = "randomBlockDisplayTick", at = @At(value = "INVOKE", target = "Lnet/minecraft/util/math/BlockPos$Mutable;set(III)Lnet/minecraft/util/math/BlockPos$Mutable;", shift = At.Shift.AFTER), cancellable = true)
    public void randomBlockDisplayTicks(int centerX, int centerY, int centerZ, int radius, class_5819 random, class_2248 block, class_2338.class_2339 pos, CallbackInfo ci) {
        float playerChunkRate = Math.min(20, TickRateClientManager.getChunkState(client.field_1724.method_31476().method_8324()).rate());
        float chunkRate = TickRateClientManager.getChunkState(class_1923.method_37232(pos)).rate();
        if(playerChunkRate > chunkRate) { // slow it down by chance if player's chunk ticking faster than the random chunk, otherwise ignore
            int chance = (int) (chunkRate / playerChunkRate * 100);
            if(chance < random.method_39332(1,100)) ci.cancel();
        }
    }

}

==> tick-0.6.0-1.21.9-sources.jar: io/github/dennisochulor/tickrate/mixin/client/tick/ClientWorldMixin.java <==
package io.github.dennisochulor.tickrate.mixin.client.tick;

import io.github.dennisochulor.tickrate.TickRateClientManager;
import net.minecraft.class_1923;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_310;
import net.minecraft.class_5819;
import net.minecraft.class_638;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_638.class)
public class ClientWorldMixin {

    @Shadow @Final private class_310 client;

    @Inject(method = "randomBlockDisplayTick", at = @At(value = "INVOKE", target = "Lnet/minecraft/util/math/BlockPos$Mutable;set(III)Lnet/minecraft/util/math/BlockPos$Mutable;", shift = At.Shift.AFTER), cancellable = true)
    public void randomBlockDisplayTicks(int centerX, int centerY, int centerZ, int radius, class_5819 random, class_2248 block, class_2338.class_2339 pos, CallbackInfo ci) {
        float playerChunkRate = Math.min(20, TickRateClientManager.getChunkState(client.field_1724.method_31476()).rate());
        float chunkRate = TickRateClientManager.getChunkState(new class_1923(pos)).rate();
        if(playerChunkRate > chunkRate) { // slow it down by chance if player's chunk ticking faster than the random chunk, otherwise ignore
            int chance = (int) (chunkRate / playerChunkRate * 100);
            if(chance < random.method_39332(1,100)) ci.cancel();
        }
    }

}
